#
# spec file for package cava
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cava
Version:        0.7.4
Release:        bp154.1.31
Summary:        Console-based Audio Visualizer for Alsa
License:        MIT
Group:          Productivity/Multimedia/Sound/Visualization
URL:            https://github.com/karlstav/cava
Source:         https://github.com/karlstav/%{name}/archive/%{version}.tar.gz
BuildRequires:  alsa-devel
BuildRequires:  fftw3-devel
# Use system ini parser instead of building own lib
BuildRequires:  libiniparser-devel >= 4.0
BuildRequires:  libpulse-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
# Installing the psf in a directory that comes from kbd
Requires:       kbd
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
C.A.V.A. is a bar spectrum audio visualizer for the Linux terminal using ALSA, pulseaudio or fifo buffer for input.

%prep
%setup -q
./autogen.sh
%configure FONT_DIR="%{_datadir}/kbd/consolefonts"

%build
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc README.md LICENSE
%{_bindir}/cava
%dir %{_datadir}/kbd/
%dir %{_datadir}/kbd/consolefonts/
%{_datadir}/kbd/consolefonts/cava.psf

%changelog
* Wed May 19 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.7.4:
  improvements:
  * added faster autosens at startup
  bugfixes:
  * better installation of custom console font
  * suppress error about vla parameter introduced in gcc11 or 10?
* Thu Oct  8 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.7.3:
  Improvements:
  * Added Hann windowing and proper ring buffer (this improves visualisation
  significantly!)
  * Added mutex lock on write to fftw input buffers and fftw execute (this
    removes som glitches)
  * Improved portaudio audio input
  * #370 made timeout configurable
  * ncurses mode is now default again
  * #379 removed key controls from noncurses to fix strange beaviour
  * Added config option: x-axis scale (frequency) #289
  Bugfixes:
  * #375 shmem audio input
  * #377 small memory leak
  * #385 fix eq
* Thu Jul  2 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.7.2:
  improvements:
  * added key controls for noncurses mode #364
  bugfixes:
  * fix drawing of background color for noncurses mode
  * fix install on macos #365
* Thu Jun 25 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.7.1:
  improvements:
  * set default gradient colors instead of exiting when not defined.
  bugfixes:
  * minor memory leak in ncurses
  * fix warnings when building on macos
  * updated macos building instructions
* Wed May 27 2020 Michael Vetter <mvetter@suse.com>
- Update 0.7.0:
  Breaking changes:
  * Reworked noncurses output mode and made it default.
    The reworked noncurses mode uses a custom framebuffer technique that
    only draws changes per frame and only writes to the terminal once per
    frame. This results in far less cpu usage then ncurses. It is also
    free of the flickering that we see in ncurses mode #196
  * Colors are no longer set by default so hopefully cava will change
    color automatically in noncurses mode when using tools such as
    pywall #340 #181
  * Unfortunately html colors, gradient and key controls are not supported
    in noncurses.
  Other improvements:
  * separated bass, midtones and treble in to separate fftw operations
* Sun May  6 2018 mvetter@suse.com
- Update to 0.6.1:
  new features:
  * sndio backend
  bug fixes:
  * Fix fftw_complex usage, drastically improving visualization
  * better cleanup and exiting
  * added a check to see if pulseaudio is running
  * fixed bug preventing color in noncurses mode from working
  * Fix build errors and warnings if not using ncurses
  * Generally improved fifo input and raw output
* Mon Aug 28 2017 mvetter@suse.com
- Update to 0.6.0:
  * Autosens of low values (dynamic range)
  * Removed config parameter 'overshoot'
  * Removed config parameter 'mode'
  * New config parameter 'waves'
  * Changed config parameter 'style' to 'channels' (was either 'mono' or 'stereo' anyway)
  * Parameters 'integral' and 'gravity' are now in percentage
* Fri Aug 18 2017 mvetter@suse.com
- Update to 0.5.0:
  new features:
  * gradient
  bugfixes:
  * memory leak
  * increased config reload speed
  * raw output not goint to /dev/stdout
* Thu Apr 27 2017 mvetter@suse.com
- Update to 0.4.3:
  new features:
  * support for more colors in ncurses output.
  bugfixes:
  * fixed bug where sensing of low values was done even when no sound
  * fixed bug in raw output bit format check
  * add a check for too many bars >200
- Remove because contained in new version:
  * cava-remove-nested-functions.patch
  * cava-font.patch
* Tue Mar 28 2017 mvetter@suse.com
- Add cava-font.patch:
  Install cava.psf to have nice output on TTYs.
* Tue Mar 28 2017 mvetter@suse.com
- Add cava-remove-nested-functions.patch:
  Remove nested functions to prevent OBS executable stack warning.
* Wed Mar 22 2017 mvetter@suse.com
- Get rid of unnecessary passing of prefix
* Thu Mar 16 2017 mvetter@suse.com
- It needs libiniparser from version 4 onwards
* Thu Mar 16 2017 mvetter@suse.com
- Update to 0.4.2:
  * added auto pulseaudio source mode
  * pulsaudio is now default
  * cava is now cavamp
  * pushing 'r' now reloads audio
  * Added console title
  * added pulseadio support
  * added confg script
  * removed commanline argumets
  * added optional config path
  * added autosens feature
  * added setting of bar width, bar spacing and frequency bandwidth to config file.
  * autodetection of alsa loopback interface
- Use proper group
- Update description
* Tue Jul 28 2015 mvetter@suse.com
- Honor optflags
* Tue Jul 28 2015 mvetter@suse.com
- Creating initial package for version 0.3.2
